@@ -1,4 +1,4 @@
 from jupyterhub_idle_culler import main
 
-if __name__ == '__main__':
-    main()
\ No newline at end of file
+if __name__ == "__main__":
+    main()
